/* xdwapi sample 10

Function :
  Gets information about the LinkRoot folder on the DocuWorks Desk.
How to use :
  xdwsmpl10
*/

#include <stdio.h>
#include <windows.h>

#include <xdw_api.h>

void print_error(int code)
{
	switch (code) {
	case XDW_E_NOT_INSTALLED:
		fprintf(stderr, "DocuWorks not installed.");
		break;
	case XDW_E_FILE_NOT_FOUND:
		fprintf(stderr, "File not found.");
		break;
	case XDW_E_ACCESSDENIED:
	case XDW_E_INVALID_NAME:
	case XDW_E_BAD_NETPATH:
		fprintf(stderr, "File not opened.");
		break;
	case XDW_E_BAD_FORMAT:
		fprintf(stderr, "File bad format.");
		break;
	case XDW_E_INVALID_ACCESS:
		fprintf(stderr, "Invalid access.");
		break;
	default:
		fprintf(stderr, "Error.");
		break;
	}
}

int main(int argc, char** argv)
{
	int api_result = 0;

	if (argc != 1) {
		fprintf(stderr, "How to use : xdwsmpl10");
		return 0;
	}

	// Get the number of LinkRoot folders in a Link folder on the DocuWorks Desk.
	int folder_num = XDW_GetLinkRootFolderNumber(NULL);
	if (folder_num < 0) {
		print_error(folder_num);
		return 0;
	} else if (folder_num == 0) {
		puts(" No LinkRoot folders.");
		return 1;
	} else {
		XDW_LINKROOTFOLDER_INFO info;
		info.nSize = sizeof(XDW_LINKROOTFOLDER_INFO);
		for (int i = 1; i <= folder_num; i++) {
			api_result = XDW_GetLinkRootFolderInformation(i, &info, NULL);
			if (api_result < 0) {
				print_error(api_result);
				break;
			}
			printf(" LinkRoot folder %ld : Path %s,  Name %s\n", i, info.szPath, info.szLinkRootFolderName);
		}
	}

	if (api_result < 0) return 0;

	return 1;
}